uriDevices = "15001"
uri_groups = "15004"


# General
attrName = "9001"
attrId = "9003"
attrDeviceInfo = "3"
attrDeviceInfo_Model = "1"
attrBatteryLevel = "9"

# Lights
attrLightControl = "3311"
attrLightState = "5850"
attrLightDimmer = "5851"
attrLightHex = "5706"
attrTransitionTime = "5712"

# Plugs
attrPlugControl = "3312"
attrPlugState = "5850"

# Blinds
attrBlindControl = "15015"
attrBlindPosition = "5536"

# Groups
attr_group_info = "15002"
attr_group_members = "9018"

# Gatewat
attr_gateway_root = "15011"
attr_gateway_reboot = "9030"